
################################################################
# This is a generated script based on design: fsys
#
# Though there are limitations about the generated script,
# the main purpose of this utility is to make learning
# IP Integrator Tcl commands easier.
################################################################

################################################################
# Check if script is running in correct Vivado version.
################################################################
set scripts_vivado_version 2015.4
set current_vivado_version [version -short]

if { [string first $scripts_vivado_version $current_vivado_version] == -1 } {
   puts ""
   puts "ERROR: This script was generated using Vivado <$scripts_vivado_version> and is being run in <$current_vivado_version> of Vivado. Please run the script in Vivado <$scripts_vivado_version> then open the design in Vivado <$current_vivado_version>. Upgrade the design by running \"Tools => Report => Report IP Status...\", then run write_bd_tcl to create an updated script."

   return 1
}

################################################################
# START
################################################################

# To test this script, run the following commands from Vivado Tcl console:
# source fsys_script.tcl

# If you do not already have a project created,
# you can create a project using the following command:
#    create_project project_1 myproj -part xc7a35tcsg324-2
#    set_property BOARD_PART trenz.biz:te0725-35-2c:part0:1.0 [current_project]

# CHECKING IF PROJECT EXISTS
if { [get_projects -quiet] eq "" } {
   puts "ERROR: Please open or create a project!"
   return 1
}



# CHANGE DESIGN NAME HERE
set design_name fsys

# If you do not already have an existing IP Integrator design open,
# you can create a design using the following command:
#    create_bd_design $design_name

# Creating design if needed
set errMsg ""
set nRet 0

set cur_design [current_bd_design -quiet]
set list_cells [get_bd_cells -quiet]

if { ${design_name} eq "" } {
   # USE CASES:
   #    1) Design_name not set

   set errMsg "ERROR: Please set the variable <design_name> to a non-empty value."
   set nRet 1

} elseif { ${cur_design} ne "" && ${list_cells} eq "" } {
   # USE CASES:
   #    2): Current design opened AND is empty AND names same.
   #    3): Current design opened AND is empty AND names diff; design_name NOT in project.
   #    4): Current design opened AND is empty AND names diff; design_name exists in project.

   if { $cur_design ne $design_name } {
      puts "INFO: Changing value of <design_name> from <$design_name> to <$cur_design> since current design is empty."
      set design_name [get_property NAME $cur_design]
   }
   puts "INFO: Constructing design in IPI design <$cur_design>..."

} elseif { ${cur_design} ne "" && $list_cells ne "" && $cur_design eq $design_name } {
   # USE CASES:
   #    5) Current design opened AND has components AND same names.

   set errMsg "ERROR: Design <$design_name> already exists in your project, please set the variable <design_name> to another value."
   set nRet 1
} elseif { [get_files -quiet ${design_name}.bd] ne "" } {
   # USE CASES: 
   #    6) Current opened design, has components, but diff names, design_name exists in project.
   #    7) No opened design, design_name exists in project.

   set errMsg "ERROR: Design <$design_name> already exists in your project, please set the variable <design_name> to another value."
   set nRet 2

} else {
   # USE CASES:
   #    8) No opened design, design_name not in project.
   #    9) Current opened design, has components, but diff names, design_name not in project.

   puts "INFO: Currently there is no design <$design_name> in project, so creating one..."

   create_bd_design $design_name

   puts "INFO: Making design <$design_name> as current_bd_design."
   current_bd_design $design_name

}

puts "INFO: Currently the variable <design_name> is equal to \"$design_name\"."

if { $nRet != 0 } {
   puts $errMsg
   return $nRet
}

##################################################################
# DESIGN PROCs
##################################################################



# Procedure to create entire design; Provide argument to make
# procedure reusable. If parentCell is "", will use root.
proc create_root_design { parentCell } {

  if { $parentCell eq "" } {
     set parentCell [get_bd_cells /]
  }

  # Get object for parentCell
  set parentObj [get_bd_cells $parentCell]
  if { $parentObj == "" } {
     puts "ERROR: Unable to find parent cell <$parentCell>!"
     return
  }

  # Make sure parentObj is hier blk
  set parentType [get_property TYPE $parentObj]
  if { $parentType ne "hier" } {
     puts "ERROR: Parent <$parentObj> has TYPE = <$parentType>. Expected to be <hier>."
     return
  }

  # Save current instance; Restore later
  set oldCurInst [current_bd_instance .]

  # Set parent object as current
  current_bd_instance $parentObj


  # Create interface ports
  set J1 [ create_bd_intf_port -mode Master -vlnv xilinx.com:interface:gpio_rtl:1.0 J1 ]
  set J2 [ create_bd_intf_port -mode Master -vlnv xilinx.com:interface:gpio_rtl:1.0 J2 ]
  set LVDS [ create_bd_intf_port -mode Slave -vlnv xilinx.com:interface:diff_clock_rtl:1.0 LVDS ]
  set UART [ create_bd_intf_port -mode Master -vlnv xilinx.com:interface:uart_rtl:1.0 UART ]

  # Create ports
  set LED [ create_bd_port -dir O -from 0 -to 0 LED ]
  set LVDS_N [ create_bd_port -dir O -from 0 -to 0 LVDS_N ]
  set LVDS_P [ create_bd_port -dir O -from 0 -to 0 LVDS_P ]
  set clk_100Mhz [ create_bd_port -dir I -type clk clk_100Mhz ]
  set_property -dict [ list \
CONFIG.FREQ_HZ {100000000} \
CONFIG.PHASE {0.000} \
 ] $clk_100Mhz
  set reset [ create_bd_port -dir I -type rst reset ]
  set_property -dict [ list \
CONFIG.POLARITY {ACTIVE_HIGH} \
 ] $reset

  # Create instance: J1_J2, and set properties
  set J1_J2 [ create_bd_cell -type ip -vlnv xilinx.com:ip:ila:6.0 J1_J2 ]
  set_property -dict [ list \
CONFIG.ALL_PROBE_SAME_MU_CNT {2} \
CONFIG.C_DATA_DEPTH {4096} \
CONFIG.C_ENABLE_ILA_AXI_MON {false} \
CONFIG.C_EN_STRG_QUAL {1} \
CONFIG.C_INPUT_PIPE_STAGES {2} \
CONFIG.C_MONITOR_TYPE {Native} \
CONFIG.C_NUM_OF_PROBES {2} \
CONFIG.C_PROBE0_MU_CNT {2} \
CONFIG.C_PROBE0_WIDTH {42} \
CONFIG.C_PROBE1_MU_CNT {2} \
CONFIG.C_PROBE1_WIDTH {42} \
CONFIG.C_TRIGIN_EN {true} \
 ] $J1_J2

  # Create instance: POF, and set properties
  set POF [ create_bd_cell -type ip -vlnv xilinx.com:ip:ila:6.0 POF ]
  set_property -dict [ list \
CONFIG.ALL_PROBE_SAME_MU {true} \
CONFIG.C_ADV_TRIGGER {false} \
CONFIG.C_DATA_DEPTH {1024} \
CONFIG.C_ENABLE_ILA_AXI_MON {false} \
CONFIG.C_INPUT_PIPE_STAGES {2} \
CONFIG.C_MONITOR_TYPE {Native} \
CONFIG.C_NUM_OF_PROBES {1} \
CONFIG.C_PROBE0_WIDTH {4} \
 ] $POF

  # Create instance: STARTUP_0, and set properties
  set STARTUP_0 [ create_bd_cell -type ip -vlnv trenz.biz:user:STARTUP:1.0 STARTUP_0 ]
  set_property -dict [ list \
CONFIG.C_INCLUDE_INTF {true} \
 ] $STARTUP_0

  # Create instance: clk_wiz_0, and set properties
  set clk_wiz_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:clk_wiz:5.2 clk_wiz_0 ]
  set_property -dict [ list \
CONFIG.CLKOUT1_JITTER {130.958} \
CONFIG.CLKOUT1_PHASE_ERROR {98.575} \
CONFIG.CLKOUT2_JITTER {209.588} \
CONFIG.CLKOUT2_PHASE_ERROR {98.575} \
CONFIG.CLKOUT2_REQUESTED_OUT_FREQ {10} \
CONFIG.CLKOUT2_USED {true} \
CONFIG.CLKOUT3_JITTER {125.247} \
CONFIG.CLKOUT3_PHASE_ERROR {98.575} \
CONFIG.CLKOUT3_REQUESTED_OUT_FREQ {125.000} \
CONFIG.CLKOUT3_USED {true} \
CONFIG.CLKOUT4_JITTER {110.209} \
CONFIG.CLKOUT4_PHASE_ERROR {98.575} \
CONFIG.CLKOUT4_REQUESTED_OUT_FREQ {250.000} \
CONFIG.CLKOUT4_USED {true} \
CONFIG.CLKOUT5_JITTER {110.209} \
CONFIG.CLKOUT5_PHASE_ERROR {98.575} \
CONFIG.CLKOUT5_REQUESTED_OUT_FREQ {250.000} \
CONFIG.CLKOUT5_REQUESTED_PHASE {90.000} \
CONFIG.CLKOUT5_USED {true} \
CONFIG.CLK_IN1_BOARD_INTERFACE {sys_clock} \
CONFIG.MMCM_CLKFBOUT_MULT_F {10.000} \
CONFIG.MMCM_CLKOUT0_DIVIDE_F {10.000} \
CONFIG.MMCM_CLKOUT1_DIVIDE {100} \
CONFIG.MMCM_CLKOUT2_DIVIDE {8} \
CONFIG.MMCM_CLKOUT3_DIVIDE {4} \
CONFIG.MMCM_CLKOUT4_DIVIDE {4} \
CONFIG.MMCM_CLKOUT4_PHASE {90.000} \
CONFIG.MMCM_DIVCLK_DIVIDE {1} \
CONFIG.NUM_OUT_CLKS {5} \
CONFIG.RESET_BOARD_INTERFACE {reset} \
CONFIG.USE_BOARD_FLOW {true} \
CONFIG.USE_RESET {true} \
 ] $clk_wiz_0

  # Create instance: freq_duty, and set properties
  set freq_duty [ create_bd_cell -type ip -vlnv xilinx.com:ip:vio:3.0 freq_duty ]
  set_property -dict [ list \
CONFIG.C_NUM_PROBE_IN {7} \
CONFIG.C_NUM_PROBE_OUT {0} \
 ] $freq_duty

  # Create instance: gpio_J1, and set properties
  set gpio_J1 [ create_bd_cell -type ip -vlnv trenz.biz:user:vector_gpio:1.0 gpio_J1 ]
  set_property -dict [ list \
CONFIG.C_GPIO_WIDTH {42} \
CONFIG.C_USE_INMUX {true} \
CONFIG.C_VECTOR_WIDTH {42} \
 ] $gpio_J1

  # Create instance: gpio_J2, and set properties
  set gpio_J2 [ create_bd_cell -type ip -vlnv trenz.biz:user:vector_gpio:1.0 gpio_J2 ]
  set_property -dict [ list \
CONFIG.C_GPIO_WIDTH {42} \
CONFIG.C_USE_INMUX {true} \
CONFIG.C_VECTOR_WIDTH {42} \
 ] $gpio_J2

  # Create instance: labx_duty, and set properties
  set labx_duty [ create_bd_cell -type ip -vlnv trenz.biz:user:labtools_fmeter:1.0 labx_duty ]
  set_property -dict [ list \
CONFIG.C_CHANNELS {3} \
CONFIG.C_MODE {1} \
 ] $labx_duty

  # Create instance: labx_freq_counter, and set properties
  set labx_freq_counter [ create_bd_cell -type ip -vlnv trenz.biz:user:labtools_fmeter:1.0 labx_freq_counter ]
  set_property -dict [ list \
CONFIG.C_CHANNELS {4} \
 ] $labx_freq_counter

  # Create instance: oversample_4x_0, and set properties
  set oversample_4x_0 [ create_bd_cell -type ip -vlnv trenz.biz:user:oversample_4x:1.0 oversample_4x_0 ]
  set_property -dict [ list \
CONFIG.C_NUM_CHANNELS {1} \
 ] $oversample_4x_0

  # Create instance: proc_sys_reset_0, and set properties
  set proc_sys_reset_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:proc_sys_reset:5.0 proc_sys_reset_0 ]

  # Create instance: uart_echo_0, and set properties
  set uart_echo_0 [ create_bd_cell -type ip -vlnv trenz.biz:user:uart_echo:1.0 uart_echo_0 ]

  # Create instance: util_ds_buf_0, and set properties
  set util_ds_buf_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:util_ds_buf:2.1 util_ds_buf_0 ]
  set_property -dict [ list \
CONFIG.C_BUF_TYPE {OBUFDS} \
 ] $util_ds_buf_0

  # Create instance: util_ds_buf_1, and set properties
  set util_ds_buf_1 [ create_bd_cell -type ip -vlnv xilinx.com:ip:util_ds_buf:2.1 util_ds_buf_1 ]

  # Create instance: vio_J1, and set properties
  set vio_J1 [ create_bd_cell -type ip -vlnv xilinx.com:ip:vio:3.0 vio_J1 ]
  set_property -dict [ list \
CONFIG.C_NUM_PROBE_OUT {3} \
CONFIG.C_PROBE_OUT0_INIT_VAL {0x00000000000} \
CONFIG.C_PROBE_OUT0_WIDTH {42} \
CONFIG.C_PROBE_OUT1_INIT_VAL {0x3FFFFFFFFFF} \
CONFIG.C_PROBE_OUT1_WIDTH {42} \
CONFIG.C_PROBE_OUT2_WIDTH {8} \
 ] $vio_J1

  # Create instance: vio_J2, and set properties
  set vio_J2 [ create_bd_cell -type ip -vlnv xilinx.com:ip:vio:3.0 vio_J2 ]
  set_property -dict [ list \
CONFIG.C_NUM_PROBE_OUT {3} \
CONFIG.C_PROBE_OUT0_WIDTH {42} \
CONFIG.C_PROBE_OUT1_INIT_VAL {0x3FFFFFFFFFF} \
CONFIG.C_PROBE_OUT1_WIDTH {42} \
CONFIG.C_PROBE_OUT2_WIDTH {8} \
 ] $vio_J2

  # Create instance: vio_SYS, and set properties
  set vio_SYS [ create_bd_cell -type ip -vlnv xilinx.com:ip:vio:3.0 vio_SYS ]
  set_property -dict [ list \
CONFIG.C_EN_PROBE_IN_ACTIVITY {0} \
CONFIG.C_NUM_PROBE_IN {1} \
CONFIG.C_NUM_PROBE_OUT {2} \
CONFIG.C_PROBE_OUT0_INIT_VAL {0x1} \
CONFIG.C_PROBE_OUT0_WIDTH {1} \
CONFIG.C_PROBE_OUT1_INIT_VAL {0x0} \
CONFIG.C_PROBE_OUT1_WIDTH {1} \
 ] $vio_SYS

  # Create instance: xlconcat_duty, and set properties
  set xlconcat_duty [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconcat:2.1 xlconcat_duty ]
  set_property -dict [ list \
CONFIG.NUM_PORTS {3} \
 ] $xlconcat_duty

  # Create instance: xlconcat_freq, and set properties
  set xlconcat_freq [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconcat:2.1 xlconcat_freq ]
  set_property -dict [ list \
CONFIG.NUM_PORTS {4} \
 ] $xlconcat_freq

  # Create instance: xmod_uart, and set properties
  set xmod_uart [ create_bd_cell -type ip -vlnv xilinx.com:ip:ila:6.0 xmod_uart ]
  set_property -dict [ list \
CONFIG.ALL_PROBE_SAME_MU_CNT {1} \
CONFIG.C_DATA_DEPTH {131072} \
CONFIG.C_ENABLE_ILA_AXI_MON {false} \
CONFIG.C_EN_STRG_QUAL {0} \
CONFIG.C_MONITOR_TYPE {Native} \
CONFIG.C_NUM_OF_PROBES {1} \
CONFIG.C_PROBE0_MU_CNT {1} \
CONFIG.C_TRIGOUT_EN {true} \
 ] $xmod_uart

  # Create interface connections
  connect_bd_intf_net -intf_net CLK_IN_D_1 [get_bd_intf_ports LVDS] [get_bd_intf_pins util_ds_buf_1/CLK_IN_D]
  connect_bd_intf_net -intf_net gpio_J1_GPIO [get_bd_intf_ports J1] [get_bd_intf_pins gpio_J1/GPIO]
  connect_bd_intf_net -intf_net gpio_J2_GPIO [get_bd_intf_ports J2] [get_bd_intf_pins gpio_J2/GPIO]
  connect_bd_intf_net -intf_net uart_echo_0_UART [get_bd_intf_ports UART] [get_bd_intf_pins uart_echo_0/UART]
  connect_bd_intf_net -intf_net xmod_uart_TRIG_OUT [get_bd_intf_pins J1_J2/TRIG_IN] [get_bd_intf_pins xmod_uart/TRIG_OUT]

  # Create port connections
  connect_bd_net -net CFGCLK [get_bd_pins freq_duty/probe_in0] [get_bd_pins labx_freq_counter/F0]
  connect_bd_net -net J1_DUTY [get_bd_pins freq_duty/probe_in3] [get_bd_pins labx_duty/F0]
  connect_bd_net -net J1_FREQ [get_bd_pins freq_duty/probe_in1] [get_bd_pins labx_freq_counter/F1]
  connect_bd_net -net J1_i [get_bd_pins J1_J2/probe0] [get_bd_pins gpio_J1/vector_i] [get_bd_pins vio_J1/probe_in0]
  connect_bd_net -net J2_DUTY [get_bd_pins freq_duty/probe_in4] [get_bd_pins labx_duty/F1]
  connect_bd_net -net J2_FREQ [get_bd_pins freq_duty/probe_in2] [get_bd_pins labx_freq_counter/F2]
  connect_bd_net -net J2_i [get_bd_pins J1_J2/probe1] [get_bd_pins gpio_J2/vector_i] [get_bd_pins vio_J2/probe_in0]
  connect_bd_net -net POF_DUTY [get_bd_pins freq_duty/probe_in6] [get_bd_pins labx_duty/F2]
  connect_bd_net -net POF_FREQ [get_bd_pins freq_duty/probe_in5] [get_bd_pins labx_freq_counter/F3]
  connect_bd_net -net POF_RXD [get_bd_pins oversample_4x_0/din_bufout] [get_bd_pins xlconcat_duty/In2] [get_bd_pins xlconcat_freq/In3]
  connect_bd_net -net STARTUP_0_user_clk [get_bd_pins J1_J2/clk] [get_bd_pins STARTUP_0/user_clk] [get_bd_pins freq_duty/clk] [get_bd_pins labx_duty/refclk] [get_bd_pins vio_J1/clk] [get_bd_pins vio_J2/clk] [get_bd_pins vio_SYS/clk] [get_bd_pins xlconcat_freq/In0]
  connect_bd_net -net STARTUP_0_user_reset [get_bd_pins STARTUP_0/user_reset] [get_bd_pins proc_sys_reset_0/ext_reset_in]
  connect_bd_net -net clk_wiz_0_clk_out1 [get_bd_pins clk_wiz_0/clk_out1] [get_bd_pins labx_freq_counter/refclk]
  connect_bd_net -net clk_wiz_0_clk_out2 [get_bd_pins clk_wiz_0/clk_out2] [get_bd_pins xmod_uart/clk]
  connect_bd_net -net clk_wiz_0_clk_out3 [get_bd_pins clk_wiz_0/clk_out3] [get_bd_pins util_ds_buf_0/OBUF_IN]
  connect_bd_net -net clk_wiz_0_clk_out4 [get_bd_pins POF/clk] [get_bd_pins clk_wiz_0/clk_out4] [get_bd_pins oversample_4x_0/Clk0] [get_bd_pins proc_sys_reset_0/slowest_sync_clk]
  connect_bd_net -net clk_wiz_0_clk_out5 [get_bd_pins clk_wiz_0/clk_out5] [get_bd_pins oversample_4x_0/Clk90]
  connect_bd_net -net clk_wiz_0_locked [get_bd_pins clk_wiz_0/locked] [get_bd_pins proc_sys_reset_0/dcm_locked]
  connect_bd_net -net gpio_J1_inmux_out [get_bd_pins gpio_J1/inmux_out] [get_bd_pins xlconcat_duty/In0] [get_bd_pins xlconcat_freq/In1]
  connect_bd_net -net gpio_J2_inmux_out [get_bd_pins gpio_J2/inmux_out] [get_bd_pins xlconcat_duty/In1] [get_bd_pins xlconcat_freq/In2]
  connect_bd_net -net oversample_4x_0_dout [get_bd_pins POF/probe0] [get_bd_pins oversample_4x_0/dout]
  connect_bd_net -net proc_sys_reset_0_peripheral_reset [get_bd_pins oversample_4x_0/Rst] [get_bd_pins proc_sys_reset_0/peripheral_reset]
  connect_bd_net -net reset_1 [get_bd_ports reset] [get_bd_pins clk_wiz_0/reset]
  connect_bd_net -net sys_clock_1 [get_bd_ports clk_100Mhz] [get_bd_pins clk_wiz_0/clk_in1]
  connect_bd_net -net util_ds_buf_0_OBUF_DS_N [get_bd_ports LVDS_N] [get_bd_pins util_ds_buf_0/OBUF_DS_N]
  connect_bd_net -net util_ds_buf_0_OBUF_DS_P [get_bd_ports LVDS_P] [get_bd_pins util_ds_buf_0/OBUF_DS_P]
  connect_bd_net -net util_ds_buf_1_IBUF_OUT [get_bd_pins oversample_4x_0/din] [get_bd_pins util_ds_buf_1/IBUF_OUT]
  connect_bd_net -net vio_J1_O [get_bd_pins gpio_J1/vector_o] [get_bd_pins vio_J1/probe_out0]
  connect_bd_net -net vio_J1_T [get_bd_pins gpio_J1/vector_t] [get_bd_pins vio_J1/probe_out1]
  connect_bd_net -net vio_J1_mux [get_bd_pins gpio_J1/inmux_sel] [get_bd_pins vio_J1/probe_out2]
  connect_bd_net -net vio_J2_O [get_bd_pins gpio_J2/vector_o] [get_bd_pins vio_J2/probe_out0]
  connect_bd_net -net vio_J2_T [get_bd_pins gpio_J2/vector_t] [get_bd_pins vio_J2/probe_out1]
  connect_bd_net -net vio_J2_mux [get_bd_pins gpio_J2/inmux_sel] [get_bd_pins vio_J2/probe_out2]
  connect_bd_net -net vio_SYS_DONE [get_bd_pins STARTUP_0/USRDONEO] [get_bd_pins STARTUP_0/USRDONETS] [get_bd_pins vio_SYS/probe_out0]
  connect_bd_net -net vio_SYS_LED [get_bd_ports LED] [get_bd_pins vio_SYS/probe_out1]
  connect_bd_net -net xlconcat_0_dout [get_bd_pins labx_freq_counter/fin] [get_bd_pins xlconcat_freq/dout]
  connect_bd_net -net xlconcat_1_dout [get_bd_pins labx_duty/fin] [get_bd_pins xlconcat_duty/dout]
  connect_bd_net -net xmod_uart_rxd [get_bd_pins uart_echo_0/dbg_rxd] [get_bd_pins vio_SYS/probe_in0] [get_bd_pins xmod_uart/probe0]

  # Create address segments

  # Perform GUI Layout
  regenerate_bd_layout -layout_string {
   comment_0: "LabX simple I/O Design",
   commentid: "comment_0|",
   font_comment_0: "10",
   guistr: "# # String gsaved with Nlview 6.5.5  2015-06-26 bk=1.3371 VDI=38 GEI=35 GUI=JA:1.6
#  -string -flagsOSRD
preplace port UART -pg 1 -y 970 -defaultsOSRD
preplace port clk_100Mhz -pg 1 -y 720 -defaultsOSRD
preplace port J1 -pg 1 -y 380 -defaultsOSRD
preplace port J2 -pg 1 -y 540 -defaultsOSRD
preplace port reset -pg 1 -y 740 -defaultsOSRD
preplace port LVDS -pg 1 -y 890 -defaultsOSRD
preplace portBus LED -pg 1 -y 490 -defaultsOSRD
preplace portBus LVDS_N -pg 1 -y 680 -defaultsOSRD
preplace portBus LVDS_P -pg 1 -y 660 -defaultsOSRD
preplace inst util_ds_buf_1 -pg 1 -lvl 2 -y 890 -defaultsOSRD
preplace inst labx_freq_counter -pg 1 -lvl 5 -y 80 -defaultsOSRD
preplace inst gpio_J1 -pg 1 -lvl 3 -y 400 -defaultsOSRD
preplace inst xlconcat_freq -pg 1 -lvl 4 -y 120 -defaultsOSRD
preplace inst gpio_J2 -pg 1 -lvl 3 -y 560 -defaultsOSRD
preplace inst uart_echo_0 -pg 1 -lvl 6 -y 980 -defaultsOSRD
preplace inst xlconcat_duty -pg 1 -lvl 4 -y 250 -defaultsOSRD
preplace inst vio_J1 -pg 1 -lvl 2 -y 400 -defaultsOSRD
preplace inst vio_J2 -pg 1 -lvl 2 -y 560 -defaultsOSRD
preplace inst proc_sys_reset_0 -pg 1 -lvl 2 -y 740 -defaultsOSRD
preplace inst xmod_uart -pg 1 -lvl 5 -y 600 -defaultsOSRD
preplace inst STARTUP_0 -pg 1 -lvl 1 -y 560 -defaultsOSRD
preplace inst POF -pg 1 -lvl 6 -y 860 -defaultsOSRD
preplace inst J1_J2 -pg 1 -lvl 6 -y 300 -defaultsOSRD
preplace inst clk_wiz_0 -pg 1 -lvl 1 -y 730 -defaultsOSRD
preplace inst vio_SYS -pg 1 -lvl 6 -y 480 -defaultsOSRD
preplace inst oversample_4x_0 -pg 1 -lvl 3 -y 860 -defaultsOSRD
preplace inst util_ds_buf_0 -pg 1 -lvl 6 -y 670 -defaultsOSRD
preplace inst labx_duty -pg 1 -lvl 5 -y 230 -defaultsOSRD
preplace inst freq_duty -pg 1 -lvl 6 -y 110 -defaultsOSRD
preplace netloc gpio_J2_GPIO 1 3 4 NJ 540 NJ 540 NJ 540 NJ
preplace netloc clk_wiz_0_locked 1 1 1 N
preplace netloc J2_i 1 1 5 280 630 NJ 630 890 330 NJ 330 NJ
preplace netloc J1_FREQ 1 5 1 1370
preplace netloc vio_SYS_LED 1 6 1 NJ
preplace netloc util_ds_buf_1_IBUF_OUT 1 2 1 NJ
preplace netloc util_ds_buf_0_OBUF_DS_N 1 6 1 NJ
preplace netloc vio_J1_mux 1 2 1 620
preplace netloc vio_J1_O 1 2 1 610
preplace netloc J1_DUTY 1 5 1 1340
preplace netloc CLK_IN_D_1 1 0 2 NJ 890 NJ
preplace netloc gpio_J1_GPIO 1 3 4 NJ 380 NJ 380 NJ 380 NJ
preplace netloc xlconcat_1_dout 1 4 1 1090
preplace netloc util_ds_buf_0_OBUF_DS_P 1 6 1 NJ
preplace netloc vio_J2_mux 1 2 1 620
preplace netloc vio_J2_O 1 2 1 610
preplace netloc sys_clock_1 1 0 1 NJ
preplace netloc POF_FREQ 1 5 1 1350
preplace netloc gpio_J1_inmux_out 1 3 1 860
preplace netloc uart_echo_0_UART 1 6 1 NJ
preplace netloc xlconcat_0_dout 1 4 1 1090
preplace netloc gpio_J2_inmux_out 1 3 1 870
preplace netloc POF_RXD 1 3 1 900
preplace netloc xmod_uart_rxd 1 4 3 1100 530 1410 550 1670
preplace netloc vio_J1_T 1 2 1 600
preplace netloc clk_wiz_0_clk_out1 1 1 4 NJ 40 NJ 40 NJ 40 1090
preplace netloc POF_DUTY 1 5 1 1380
preplace netloc J2_DUTY 1 5 1 1360
preplace netloc proc_sys_reset_0_peripheral_reset 1 2 1 610
preplace netloc clk_wiz_0_clk_out2 1 1 4 NJ 640 NJ 640 NJ 590 N
preplace netloc STARTUP_0_user_reset 1 1 1 270
preplace netloc CFGCLK 1 5 1 1380
preplace netloc vio_J2_T 1 2 1 600
preplace netloc clk_wiz_0_clk_out3 1 1 5 NJ 650 NJ 650 NJ 650 NJ 670 N
preplace netloc STARTUP_0_user_clk 1 1 5 260 320 NJ 320 NJ 320 1100 320 1390
preplace netloc J1_i 1 1 5 270 470 NJ 470 880 340 NJ 310 NJ
preplace netloc xmod_uart_TRIG_OUT 1 5 1 1400
preplace netloc reset_1 1 0 1 NJ
preplace netloc clk_wiz_0_clk_out4 1 1 5 280 830 620 780 NJ 780 NJ 780 1370
preplace netloc vio_SYS_DONE 1 0 7 20 940 NJ 940 NJ 940 NJ 920 NJ 920 NJ 920 1680
preplace netloc oversample_4x_0_dout 1 3 3 N 870 NJ 870 NJ
preplace netloc clk_wiz_0_clk_out5 1 1 2 NJ 840 600
preplace netloc J2_FREQ 1 5 1 1360
preplace cgraphic comment_0 place abs 506 148 textcolor 4 linecolor 3 linewidth 2
levelinfo -pg 1 0 130 440 740 1000 1230 1550 1700 -top 0 -bot 1040
",
}

  # Restore current instance
  current_bd_instance $oldCurInst

  save_bd_design
}
# End of create_root_design()


##################################################################
# MAIN FLOW
##################################################################

create_root_design ""


